############################################################
#Leitprogramm Kapitel 7: Statistische Modelle
#
#
#K. Rosin (Oktober 2008)
############################################################


#-----------------------------------------------------------
#Kapitel 7.2: Diskrete Verteilungen
#-----------------------------------------------------------

#Binomialverteilung
    dbinom(1,3,0.05)
    dbinom(0,3,0.05)
    dbinom(0,3,0.05) + dbinom(1,3,0.05)
    pbinom(1,3,0.05)

#Lsungen zu bungsaufgabe 7.1
    dbinom(1,10,1/100)
    1 - pbinom(1,10,1/100)


#-----------------------------------------------------------
#Kapitel 7.3: Stetige Verteilungen
#-----------------------------------------------------------

#Daten importieren
    PINE_PFAD <- "E:/Prop/R/3_Daten/Pine_River.csv"
    Pi <- read.table(PINE_PFAD, sep = ";", dec = ",", header = T)
    names(Pi); dim(Pi)
    head(Pi)

#Familie der Verteilung
    n <- length(Pi$Abfluss)
    Femp <- 1:n/(n+1)

    PI_FEMP_PFAD <- "E:/Prop/R/temp/Pine_Empirische_Verteilung.bmp"
    bmp(PI_FEMP_PFAD, width = 350, height = 350)
    par(cex = 1.1, mar = c(5.1, 4.1, 1.5, 1.5))
        plot(sort(Pi$Abfluss), Femp, xlim = c(0,5000), ylim = c(0,1),
            xlab = "Abfluss [m/s]", ylab = "Femp [-]", type = "s", col = "red")
    dev.off()

#Parameterschtzung

    #Parameter der Lognormalverteilung mit MLE-Methode schtzen
    require(MASS)
    Fit_Pi  <- fitdistr(Pi$Abfluss, "lognormal")
    mlog_Pi <- as.numeric(Fit_Pi$estimate[1])
    slog_Pi <- as.numeric(Fit_Pi$estimate[2])

    #Parameter der Gumbelverteilung mit MoM-Methode schtzen
    a_Pi <- mean(Pi$Abfluss) - 0.4500535 * sd(Pi$Abfluss)
    b_Pi <- sqrt(6)/pi * sd(Pi$Abfluss)

#Verteilungen testen
    #install.packages("evd")
    require(evd)
    ks.test(Pi$Abfluss, "plnorm", mlog_Pi, slog_Pi)
    ks.test(Pi$Abfluss, "pgumbel", a_Pi, b_Pi)

#Modelle anwenden
    qlnorm(0.99, mlog_Pi, slog_Pi)
    qgumbel(0.99, a_Pi, b_Pi)
    
#Lsungen zu bungsaufgabe 7.2
    ZUFALL <- runif (1000, 5, 8)

    a_ZUFALL <- mean(ZUFALL) - sqrt(3) * sd(ZUFALL)
    b_ZUFALL <- mean(ZUFALL) + sqrt(3) * sd(ZUFALL)

    Fit_ZUFALL <- fitdistr(ZUFALL, "normal")
    m_ZUFALL <- as.numeric(Fit_ZUFALL$estimate[1])
    s_ZUFALL <- as.numeric(Fit_ZUFALL$estimate[2])

    ks.test(ZUFALL, "punif", a_ZUFALL, b_ZUFALL)
    ks.test(ZUFALL, "pnorm", m_ZUFALL, s_ZUFALL)


#-----------------------------------------------------------
#Kapitel 7.4: Einfache Lineare Regression
#-----------------------------------------------------------

#Daten importieren
    O2_PFAD <- "E:/Prop/R/3_Daten/Weil_O2.csv"
    O2 <- read.table(O2_PFAD, sep = ";", dec = ",", header = T)
    names(O2); dim(O2)
    head(O2)

    plot(O2$Temp, O2$O2)

#Einfaches Lineares Modell
    W_Modell_1 <- lm (O2$O2 ~ O2$Temp)
    summary(W_Modell_1)

#Annahmen berprfen
    ANN_MOD1_PFAD <- "E:/Prop/R/temp/Annahmen_W_Modell_1.bmp"
    bmp(ANN_MOD1_PFAD, width = 600, height = 600)
        par(mfrow = c(2, 2))
        plot(W_Modell_1, which = c(1,2,4,5))
    dev.off()

#Variablentransformation
    Temp2 <- sqrt(O2$Temp)
    plot(Temp2, O2$O2)

#Zweites Modell
    W_Modell_2 <- lm(O2$O2 ~ Temp2)
    summary(W_Modell_2)

#Annahmen berprfen
    ANN_MOD2_PFAD <- "E:/Prop/R/temp/Annahmen_W_Modell_2.bmp"
    bmp(ANN_MOD2_PFAD, width = 600, height = 600)
        par(mfrow = c(2, 2))
        plot(W_Modell_2, which = c(1,2,4,5))
    dev.off()

#Konfidenz- und Prognoseintervalle
    plot(Temp2, O2$O2)
    abline(W_Modell_2)

    SEQ <- seq(2, 5, 0.1)
    CONF_W <- predict.lm(W_Modell_2, data.frame(Temp2 = SEQ),
        interval="confidence", level= 0.95)
    PRED_W <- predict.lm(W_Modell_2, data.frame(Temp2 = SEQ),
        interval="prediction", level= 0.95)

#Transformierte Variable (Temp2)
    plot(Temp2, O2$O2)
    		points(SEQ, CONF_W[,"fit"], type = "l", lty = 1)
    		points(SEQ, CONF_W[,"lwr"], type = "l", lty = 2)
    		points(SEQ, CONF_W[,"upr"], type = "l", lty = 2)
    		points(SEQ, PRED_W[,"lwr"], type = "l", lty = 3)
    		points(SEQ, PRED_W[,"upr"], type = "l", lty = 3)

#Nicht transformierte Variable (O2$Temp)
    W_KI_PI_PFAD <- "E:/Prop/R/temp/W_KI_PI.bmp"
    bmp(W_KI_PI_PFAD, width = 400, height = 400)
        plot(O2$Temp, O2$O2)
            points(SEQ^2, CONF_W[,"fit"], type = "l", lty = 1)
            points(SEQ^2, CONF_W[,"lwr"], type = "l", lty = 2)
            points(SEQ^2, CONF_W[,"upr"], type = "l", lty = 2)
            points(SEQ^2, PRED_W[,"lwr"], type = "l", lty = 3)
            points(SEQ^2, PRED_W[,"upr"], type = "l", lty = 3)
    dev.off()

#Lsungen zu bungsaufgabe 7.3
    #Daten importieren
    HUG_PFAD <- "E:/Prop/R/3_Daten/HydroUG.csv"
    HUG <- read.table(HUG_PFAD, sep = ";", dec = ",", header = T)
    names(HUG); dim(HUG)
    HUG[1:10,]

    #Variablentransformation
    Q06A <- log(HUG$Q06)
    plot(Q06A, HUG$P06)
    HUG_Modell_1 <- lm (HUG$P06 ~ Q06A)

    #Annahmen berprfen
    ANN_HUG1_PFAD <- "E:/Prop/R/temp/Annahmen_HUG_Modell_1.bmp"
    bmp(ANN_HUG1_PFAD, width = 600, height = 600)
        par(mfrow = c(2, 2))
        plot(HUG_Modell_1, which = c(1,2,4,5))
    dev.off()

    #Zusammenfassung
    summary(HUG_Modell_1)
    
#Konfidenz- und Prognoseintervalle
    SEQ <- seq(6.4,7.4,0.05)
    CONF_HUG <- predict.lm(HUG_Modell_1, data.frame(Q06A = SEQ),
        interval="confidence", level= 0.95)

    HUG_KI_PI_PFAD <- "E:/Prop/R/temp/HUG_KI_PI.bmp"
    bmp(HUG_KI_PI_PFAD, width = 450, height = 400)
        plot(HUG$Q06, HUG$P06)
        points(exp(SEQ), CONF_HUG[,"fit"], type = "l", lty = 1)
        points(exp(SEQ), CONF_HUG[,"lwr"], type = "l", lty = 2)
        points(exp(SEQ), CONF_HUG[,"upr"], type = "l", lty = 2)
    dev.off()


#-----------------------------------------------------------
#Kapitel 7.5: Multiple Lineare Regression
#-----------------------------------------------------------

    HUG_Modell_2 <- lm(HUG$P06 ~ HUG$HOEHE + HUG$WALD + HUG$BEVD + HUG$GEWD)
    summary(HUG_Modell_2)

    HUG_Modell_2 <- lm(HUG$P06 ~ HUG$HOEHE + HUG$WALD + HUG$GEWD)
    summary(HUG_Modell_2)

    HUG_Modell_2 <- lm(HUG$P06 ~ HUG$HOEHE + HUG$WALD)
    summary(HUG_Modell_2)

#Annahmen berprfen
    ANN_HUG2_PFAD <- "E:/Prop/R/temp/Annahmen_HUG_Modell_2.bmp"
    bmp(ANN_HUG2_PFAD, width = 600, height = 600)
        par(mfrow = c(2, 2))
        plot(HUG_Modell_2, which = c(1,2,4,5))
    dev.off()

#Modell anwenden
    PRED_HUG_2 <- predict.lm(HUG_Modell_2,
        data.frame(HOEHE = HUG$HOEHE, WALD = HUG$WALD),
        interval="prediction", level= 0.95)

#Lsungen zu bungsaufgabe 7.4
    HUG_Modell_3 <- lm(HUG$DURCH ~ HUG$HOEHE + HUG$P06 + HUG$WALD)
    summary(HUG_Modell_3)

    HUG_Modell_3 <- lm (HUG$DURCH ~ HUG$HOEHE + HUG$P06)
    summary(HUG_Modell_3)

    HUG_Modell_3 <- lm (HUG$DURCH ~ HUG$HOEHE + HUG$P06 -1)
    summary(HUG_Modell_3)

    HUG_Modell_3 <- lm (HUG$DURCH ~ HUG$HOEHE -1)
    summary(HUG_Modell_3)

#Annahmen berprfen
    ANN_HUG3_PFAD <- "E:/Prop/R/temp/Annahmen_HUG_Modell_3.bmp"
    bmp(ANN_HUG3_PFAD, width = 600, height = 600)
        par(mfrow = c(2, 2))
        plot(HUG_Modell_3, which = c(1,2,4,5))
    dev.off()

